==> react-atom-tag-2.44.0.tgz: package/lib/Standard.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import cx from 'classnames';
import PropTypes from 'prop-types';
import { onHandler } from './constants.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var StandardTag = function StandardTag(_ref) {
  var className = _ref.className,
      closeIcon = _ref.closeIcon,
      icon = _ref.icon,
      label = _ref.label,
      onClose = _ref.onClose,
      value = _ref.value,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      title = _ref.title;
  var classNames = cx(className, closeIcon && 'sui-AtomTag-hasClose');
  return /*#__PURE__*/_jsxs("span", _extends({
    className: classNames
  }, disabled && {
    'aria-disabled': disabled
  }, readOnly && !disabled && {
    'aria-readonly': readOnly
  }, {
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-icon",
      children: icon
    }), /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-label",
      title: title || label,
      children: label
    }), closeIcon && !(disabled || readOnly) && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-closeable",
      onClick: onHandler({
        disabled: disabled,
        readOnly: readOnly
      }, onClose, {
        value: value,
        label: label
      }),
      children: /*#__PURE__*/_jsx("span", {
        className: "sui-AtomTag-closeableIcon sui-AtomTag-secondary-icon",
        children: closeIcon
      })
    })]
  }));
};

export default StandardTag;

==> react-atom-tag-2.47.0.tgz: package/lib/Standard.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import cx from 'classnames';
import PropTypes from 'prop-types';
import { onHandler } from './constants.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var StandardTag = function StandardTag(_ref) {
  var className = _ref.className,
    closeIcon = _ref.closeIcon,
    icon = _ref.icon,
    label = _ref.label,
    onClose = _ref.onClose,
    value = _ref.value,
    readOnly = _ref.readOnly,
    disabled = _ref.disabled,
    title = _ref.title;
  var classNames = cx(className, closeIcon && 'sui-AtomTag-hasClose');
  return /*#__PURE__*/_jsxs("span", _extends({
    className: classNames
  }, disabled && {
    'aria-disabled': disabled
  }, readOnly && !disabled && {
    'aria-readonly': readOnly
  }, {
    children: [icon && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-icon",
      children: icon
    }), label ? /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-label",
      title: title || label,
      children: label
    }) : null, closeIcon && !(disabled || readOnly) && /*#__PURE__*/_jsx("span", {
      className: "sui-AtomTag-closeable",
      onClick: onHandler({
        disabled: disabled,
        readOnly: readOnly
      }, onClose, {
        value: value,
        label: label
      }),
      children: /*#__PURE__*/_jsx("span", {
        className: "sui-AtomTag-closeableIcon sui-AtomTag-secondary-icon",
        children: closeIcon
      })
    })]
  }));
};
export default StandardTag;
